@@ -1,4 +1,4 @@
-""" Discogs cover source. """
+"""Discogs cover source."""
 
 import collections
 import json
@@ -11,7 +11,6 @@ FUZZY_MODE = False
 
 
 class DiscogsCoverSourceResult(CoverSourceResult):
-
     """Discogs search cover result."""
 
     def __init__(self, *args, **kwargs):
@@ -24,7 +23,6 @@ class DiscogsCoverSourceResult(CoverSourceResult):
 
 
 class DiscogsCoverSource(CoverSource):
-
     """
     Cover source using the official API.
 
@@ -56,7 +54,7 @@ class DiscogsCoverSource(CoverSource):
         headers["Accept"] = "application/vnd.discogs.v2.discogs+json"
         headers["Authorization"] = f"Discogs key={__class__.API_KEY}, secret={__class__.API_SECRET}"
 
-    async def parseResults(self, api_data):
+    async def parseResults(self, api_data, *, search_album, search_artist):
         """See CoverSource.parseResults."""
         json_data = json.loads(api_data)
 
